boofun.core.auto\_representation
================================

.. automodule:: boofun.core.auto_representation


   .. rubric:: Functions

   .. autosummary::

      auto_select_representation
      estimate_sparsity
      optimize_representation
      recommend_representation

   .. rubric:: Classes

   .. autosummary::

      AdaptiveFunction
